@@ -18,7 +18,10 @@ SERIAL_STOPLIST = [
     "_decl_class_registry",
     "_sa_class_manager",
     "_sa_instance_state",
+    "__repr__",
+    "__table__",
     "db",
+    "delete",
     "deserialize",
     "get_serial_field_list",
     "metadata",
@@ -26,6 +29,7 @@ SERIAL_STOPLIST = [
     "save",
     "serialize",
     "to_dict",
+    "validate_record",
     "SERIAL_STOPLIST",
     "SERIAL_LIST",
     "RELATION_SERIAL_LISTS"
@@ -34,8 +38,7 @@ SERIAL_STOPLIST = [
 
 def _eval_value(
         value, to_camel_case, level_limits, source_class,
-        relation_serial_lists
-    ):
+        relation_serial_lists):
     """ _eval_value
 
     This function converts some of the standard values as needed based
@@ -64,9 +67,9 @@ def _eval_value(
     elif isinstance(value, Decimal):
         result = str(value)
     elif isinstance(value, uuid.UUID):
-        result = str(value)
+        result = str(value).replace('-', '')
     elif isinstance(value, list):
-        if len(value) > 0:
+        if value:
             result, level_limits = _eval_value_list(
                 value,
                 to_camel_case,
@@ -92,8 +95,7 @@ def _eval_value(
 
 def _eval_value_model(
         value, to_camel_case, level_limits, source_class,
-        relation_serial_lists
-    ):
+        relation_serial_lists):
     """_eval_value_model
 
     if any class within level_limits i self-referential it gets
@@ -126,8 +128,7 @@ def _eval_value_model(
 
 def _eval_value_list(
         value, to_camel_case, level_limits, source_class,
-        relation_serial_lists
-    ):
+        relation_serial_lists):
     """_eval_value_list
 
     This function handles values that are lists. While a list that is not
